-- Auto-generated by DMS Matugen hook — do not edit manually.
-- Remove require("dms.colors") from hyprland.lua to override.

hl.config({
	general = {
		col = {
			active_border = "rgb({{colors.primary.default.hex_stripped}})",
			inactive_border = "rgb({{colors.outline.default.hex_stripped}})",
		},
	},
	group = {
		col = {
			border_active = "rgb({{colors.primary.default.hex_stripped}})",
			border_inactive = "rgb({{colors.outline.default.hex_stripped}})",
			border_locked_active = "rgb({{colors.error.default.hex_stripped}})",
			border_locked_inactive = "rgb({{colors.outline.default.hex_stripped}})",
		},
		groupbar = {
			col = {
				active = "rgb({{colors.primary.default.hex_stripped}})",
				inactive = "rgb({{colors.outline.default.hex_stripped}})",
				locked_active = "rgb({{colors.error.default.hex_stripped}})",
				locked_inactive = "rgb({{colors.outline.default.hex_stripped}})",
			},
		},
	},
})
